@@ -14,23 +14,23 @@
 
   obj = [super createBegin: aZone];
 
-  obj->numBFagents = 30;
+  obj->numBFagents = 50;
   obj->initholding = 1;
-  obj->initialcash = 10000;
-  obj->minholding = 0;
-  obj->mincash = 0;
+  obj->initialcash = 20000;
+  obj->minholding = -1;
+  obj->mincash = -100;
   obj->intrate = 0.1;
   obj->baseline = 10;
   obj->mindividend = 0.00005;
   obj->maxdividend = 100;
   obj->amplitude = 0.14178;
-  obj->period = .99;
+  obj->period = 100;
   obj->maxprice = 500;
   obj->minprice = 0.001;
   obj->taup = 50.0;
   obj->exponentialMAs = 1;
-  obj->sptype = 2;                   //0 = REE, 1 = SLOPE, 2 = ETA
-  obj->maxiterations = 10;
+  obj->sptype = 1;                   //0 = REE, 1 = SLOPE, 2 = ETA
+  obj->maxiterations = 20;
   obj->minexcess = 0.01;
   obj->eta = 0.0005;
   obj->etamax = 0.05;
@@ -38,10 +38,8 @@
   obj->rea = 9.0;
   obj->reb = 2.0;
   obj->randomSeed = 0;
- 
-  //The BFagent sets these internally.
   obj->tauv = 50.0;
-  obj->lambda = 0.3;               
+  obj->lambda = 1;                 //BFagent lambda and initvar set internally
   obj->maxbid = 10.0;
   obj->initvar = .4000212;
   obj->maxdev = 100;
